@@ -1,4 +1,5 @@
-from pymysql import cursors, OperationalError, Warning
+from pymysql import cursors, OperationalError
+from pymysql.constants import ER
 from pymysql.tests import base
 
 import os
@@ -35,7 +36,8 @@ class TestLoadLocal(base.PyMySQLTestCase):
         )
         try:
             c.execute(
-                f"LOAD DATA LOCAL INFILE '{filename}' INTO TABLE test_load_local FIELDS TERMINATED BY ','"
+                f"LOAD DATA LOCAL INFILE '{filename}' INTO TABLE test_load_local"
+                + " FIELDS TERMINATED BY ','"
             )
             c.execute("SELECT COUNT(*) FROM test_load_local")
             self.assertEqual(22749, c.fetchone()[0])
@@ -52,7 +54,8 @@ class TestLoadLocal(base.PyMySQLTestCase):
         )
         try:
             c.execute(
-                f"LOAD DATA LOCAL INFILE '{filename}' INTO TABLE test_load_local FIELDS TERMINATED BY ','"
+                f"LOAD DATA LOCAL INFILE '{filename}' INTO TABLE test_load_local"
+                + " FIELDS TERMINATED BY ','"
             )
             c.execute("SELECT COUNT(*) FROM test_load_local")
             self.assertEqual(22749, c.fetchone()[0])
@@ -63,6 +66,37 @@ class TestLoadLocal(base.PyMySQLTestCase):
             c = conn.cursor()
             c.execute("DROP TABLE test_load_local")
 
+    def test_load_warnings(self):
+        """Test load local infile produces the appropriate warnings"""
+        conn = self.connect()
+        c = conn.cursor()
+        c.execute("CREATE TABLE test_load_local (a INTEGER, b INTEGER)")
+        filename = os.path.join(
+            os.path.dirname(os.path.realpath(__file__)),
+            "data",
+            "load_local_warn_data.txt",
+        )
+        try:
+            c.execute(
+                (
+                    "LOAD DATA LOCAL INFILE '{0}' INTO TABLE "
+                    + "test_load_local FIELDS TERMINATED BY ','"
+                ).format(filename)
+            )
+            self.assertEqual(1, c.warning_count)
+
+            c.execute("SHOW WARNINGS")
+            w = c.fetchone()
+
+            self.assertEqual(ER.TRUNCATED_WRONG_VALUE_FOR_FIELD, w[1])
+            self.assertIn(
+                "incorrect integer value",
+                w[2].lower(),
+            )
+        finally:
+            c.execute("DROP TABLE test_load_local")
+            c.close()
+
 
 if __name__ == "__main__":
     import unittest
